==> AlwaysMoreItems-1.3.1-sources.jar: net/glasslauncher/mods/alwaysmoreitems/mixin/client/class_555Mixin.java <==
package net.glasslauncher.mods.alwaysmoreitems.mixin.client;

import net.glasslauncher.mods.alwaysmoreitems.gui.Tooltip;
import net.glasslauncher.mods.alwaysmoreitems.gui.screen.OverlayScreen;
import net.minecraft.class_293;
import net.minecraft.class_300;
import net.minecraft.class_31;
import net.minecraft.class_32;
import net.minecraft.class_555;
import net.minecraft.client.Minecraft;
import net.modificationstation.stationapi.api.StationAPI;
import net.modificationstation.stationapi.api.client.event.gui.screen.container.TooltipRenderEvent;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Redirect;

@Mixin(class_555.class)
public class class_555Mixin {

    @Redirect(method = "method_1844", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/gui/screen/Screen;render(IIF)V"))
    private void iAmNoLongerSuggesting(class_32 instance, int mouseX, int mouseY, float delta) {
        if (OverlayScreen.INSTANCE.recipesGui.isActive() && instance instanceof class_293) {
            OverlayScreen.INSTANCE.method_118(mouseX, mouseY, delta);
        }
        else {
            instance.method_118(mouseX, mouseY, delta);
        }

        if (Tooltip.INSTANCE.isEmpty()) {
            return;
        }

        TooltipRenderEvent.TooltipRenderEventBuilder<?, ?> builder = TooltipRenderEvent.builder()
                .mouseX(mouseX)
                .mouseY(mouseY)
                .delta(delta)
                .textManager(Minecraft.field_2791.field_2815)
                .inventory(Minecraft.field_2791.field_2806.field_519)
                ;

        class_31 itemStack = Tooltip.INSTANCE.getItemStack();
        if (itemStack != null) {
                builder
                        .originalTooltip(class_300.method_992().method_993(itemStack.method_726() + ".name"))
                        .itemStack(itemStack)
                ;
        }
        else {
            builder.originalTooltip("");
        }

        builder.container(Tooltip.INSTANCE.getContainerScreen());

        TooltipRenderEvent event = builder.build();

        StationAPI.EVENT_BUS.post(event);
        Tooltip.INSTANCE.clear();
    }
}

==> AlwaysMoreItems-1.7.1-sources.jar: net/glasslauncher/mods/alwaysmoreitems/mixin/client/class_555Mixin.java <==
package net.glasslauncher.mods.alwaysmoreitems.mixin.client;

import net.glasslauncher.mods.alwaysmoreitems.gui.Tooltip;
import net.glasslauncher.mods.alwaysmoreitems.gui.screen.OverlayScreen;
import net.minecraft.class_293;
import net.minecraft.class_300;
import net.minecraft.class_31;
import net.minecraft.class_32;
import net.minecraft.class_555;
import net.minecraft.client.Minecraft;
import net.modificationstation.stationapi.api.StationAPI;
import net.modificationstation.stationapi.api.client.event.gui.screen.container.TooltipRenderEvent;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Redirect;

@Mixin(class_555.class)
public class class_555Mixin {

    @Redirect(method = "onFrameUpdate", at = @At(value = "INVOKE", target = "Lnet/minecraft/client/gui/screen/Screen;render(IIF)V"))
    private void iAmNoLongerSuggesting(class_32 instance, int mouseX, int mouseY, float delta) {
        if (OverlayScreen.INSTANCE.recipesGui.isActive() && instance instanceof class_293) {
            OverlayScreen.INSTANCE.method_118(mouseX, mouseY, delta);
        }
        else {
            instance.method_118(mouseX, mouseY, delta);
        }

        if (Tooltip.INSTANCE.isEmpty()) {
            return;
        }

        TooltipRenderEvent.TooltipRenderEventBuilder<?, ?> builder = TooltipRenderEvent.builder()
                .mouseX(mouseX)
                .mouseY(mouseY)
                .delta(delta)
                .textManager(Minecraft.field_2791.field_2815)
                .inventory(Minecraft.field_2791.field_2806.field_519)
                ;

        class_31 itemStack = Tooltip.INSTANCE.getItemStack();
        if (itemStack != null) {
                builder
                        .originalTooltip(class_300.method_992().method_993(itemStack.method_726() + ".name"))
                        .itemStack(itemStack)
                ;
        }
        else {
            builder.originalTooltip("");
        }

        builder.container(Tooltip.INSTANCE.getContainerScreen());

        TooltipRenderEvent event = builder.build();

        StationAPI.EVENT_BUS.post(event);
        Tooltip.INSTANCE.clear();
    }
}
